<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Devices.WiFi

Windows Runtime (WinRT) APIs for for the `Windows.Devices.WiFi` namespace.

This package provides the `winrt.windows.devices.wifi` module.
